# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class InputNumber(Component):
    """An InputNumber component.


Keyword arguments:

- id (string; optional)

- className (string; optional)

- value (number | string; default 0)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = 'InputNumber'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, value=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(InputNumber, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MobileDropdown(Component):
    """A MobileDropdown component.


Keyword arguments:

- id (string; optional)

- className (string; optional)

- clearable (boolean; default True)

- notfoundMsg (string; optional)

- options (list; optional)

- value (string | number; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = 'MobileDropdown'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, options=Component.UNDEFINED, value=Component.UNDEFINED, notfoundMsg=Component.UNDEFINED, clearable=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'clearable', 'notfoundMsg', 'options', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'clearable', 'notfoundMsg', 'options', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(MobileDropdown, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class IosScrollWrapper(Component):
    """An IosScrollWrapper component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = 'IosScrollWrapper'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(IosScrollWrapper, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class LoadingWrapper(Component):
    """A LoadingWrapper component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- className (string; optional)

- ignores (list of strings; optional)

- interval (number; default 1000)

- is_loading (boolean; optional)

- is_stop (boolean; default False)

- targetClassName (string; required)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = 'LoadingWrapper'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, targetClassName=Component.REQUIRED, interval=Component.UNDEFINED, ignores=Component.UNDEFINED, is_loading=Component.UNDEFINED, is_stop=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'ignores', 'interval', 'is_loading', 'is_stop', 'targetClassName']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'ignores', 'interval', 'is_loading', 'is_stop', 'targetClassName']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['targetClassName']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(LoadingWrapper, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Alert(Component):
    """An Alert component.


Keyword arguments:

- id (string; optional)

- buttons (list of dicts; required)

- duration (number; default 150)

- is_open (boolean; default False)

- message (a list of or a singular dash component, string or number; required)

- output_target (boolean | number | string | dict | list; optional)

- title (a list of or a singular dash component, string or number; optional)

- value (string | number; optional)"""
    _children_props = ['message', 'title']
    _base_nodes = ['message', 'title', 'children']
    _namespace = 'thinks_dash_components'
    _type = 'Alert'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, message=Component.REQUIRED, title=Component.UNDEFINED, buttons=Component.REQUIRED, value=Component.UNDEFINED, is_open=Component.UNDEFINED, duration=Component.UNDEFINED, output_target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttons', 'duration', 'is_open', 'message', 'output_target', 'title', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttons', 'duration', 'is_open', 'message', 'output_target', 'title', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['buttons', 'message']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Alert, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class _ComponentTemplate(Component):
    """A _ComponentTemplate component.
ExampleComponent is an example component.
It takes a property, `label`, and
displays it.
It renders an input with the property `value`
which is editable by the user.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- label (string; required):
    A label that will be printed when this component is rendered.

- value (string; optional):
    The value displayed in the input."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = '_ComponentTemplate'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, label=Component.REQUIRED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'label', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'label', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(_ComponentTemplate, self).__init__(**args)



from .Alert import Alert
from .DesignableRadioItems import DesignableRadioItems
from .IndexedDB import IndexedDB
from .InputNumber import InputNumber
from .IosScrollWrapper import IosScrollWrapper
from .LoadingWrapper import LoadingWrapper
from .MobileDropdown import MobileDropdown
from .Notice import Notice
from .Rotate import Rotate
from .SelectableBox import SelectableBox
from .StorageObserver import StorageObserver
from .TouchableComponent import TouchableComponent
from .UrlObserver import UrlObserver
from ._ComponentTemplate import _ComponentTemplate

__all__ = [
    "Alert",
    "DesignableRadioItems",
    "IndexedDB",
    "InputNumber",
    "IosScrollWrapper",
    "LoadingWrapper",
    "MobileDropdown",
    "Notice",
    "Rotate",
    "SelectableBox",
    "StorageObserver",
    "TouchableComponent",
    "UrlObserver",
    "_ComponentTemplate"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SelectableBox(Component):
    """A SelectableBox component.


Keyword arguments:

- id (string; optional)

- className (string; default '')

- optionChildren (list of a list of or a singular dash component, string or numbers; required)

- optionValues (list of string | numbers; required)

- value (string | number; optional)"""
    _children_props = ['optionChildren']
    _base_nodes = ['optionChildren', 'children']
    _namespace = 'thinks_dash_components'
    _type = 'SelectableBox'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, optionChildren=Component.REQUIRED, optionValues=Component.REQUIRED, value=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'optionChildren', 'optionValues', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'optionChildren', 'optionValues', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['optionChildren', 'optionValues']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(SelectableBox, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class IndexedDB(Component):
    """An IndexedDB component.


Keyword arguments:

- id (string; required)

- db_name (string; required)

- exe_delete (dict | list; optional)

- exe_delete_all (dict | list; optional)

- exe_get_key_all (dict | list; optional)

- exe_insert (dict | list; optional)

- exe_select (dict | list; optional)

- exe_select_all (dict | list; optional)

- exe_update (dict | list; optional)

- get_result (dict; optional)

- is_delete (boolean; default False)

- select_result (dict; optional)

- stores (list of dicts; required)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'thinks_dash_components'
    _type = 'IndexedDB'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, is_delete=Component.UNDEFINED, db_name=Component.REQUIRED, stores=Component.REQUIRED, exe_insert=Component.UNDEFINED, exe_update=Component.UNDEFINED, exe_delete=Component.UNDEFINED, exe_delete_all=Component.UNDEFINED, exe_select=Component.UNDEFINED, exe_select_all=Component.UNDEFINED, exe_get_key_all=Component.UNDEFINED, select_result=Component.UNDEFINED, get_result=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'db_name', 'exe_delete', 'exe_delete_all', 'exe_get_key_all', 'exe_insert', 'exe_select', 'exe_select_all', 'exe_update', 'get_result', 'is_delete', 'select_result', 'stores']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'db_name', 'exe_delete', 'exe_delete_all', 'exe_get_key_all', 'exe_insert', 'exe_select', 'exe_select_all', 'exe_update', 'get_result', 'is_delete', 'select_result', 'stores']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id', 'db_name', 'stores']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(IndexedDB, self).__init__(**args)



import json

from setuptools import setup

with open("package.json", encoding="utf-8") as f:
    package = json.load(f)


def load_readme() -> str:
    with open("README.md", encoding="utf-8") as fin:
        return fin.read()


package_name = package["name"].replace(" ", "_").replace("-", "_")

setup(
    name=package_name,
    version=package["version"],
    author=package["author"],
    packages=[package_name],
    include_package_data=True,
    license=package["license"],
    description=package.get("description", package_name),
    long_description=load_readme(),
    long_description_content_type="text/markdown",
    install_requires=[],
    classifiers=[
        "Framework :: Dash",
    ],
)
